@@ -16,7 +16,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = '0.13';
+our $VERSION = '0.15';
 
 our $errcode = 0;
 our $errmsg  = '';
@@ -164,6 +164,13 @@ sub token {
     $self->show;
 }
 
+sub tok_maybe {
+    my $self = shift;
+    my $tk = shift;
+    $self->{token} = ref($tk) eq 'ARRAY' ? $tk : [$tk];
+    $self->show_maybe;
+}
+
 sub DESTROY {
     my $self = shift;
     $self->close;
@@ -224,6 +231,9 @@ sub show {
                 my $min  = int(($unit % 3600) / 60);
                 my $sec  = $unit % 60;
                 my $stamp = sprintf '%02d:%02d:%02d', $hour, $min, $sec;
+
+                $stamp = substr($stamp, -$len) if length($stamp) > $len;
+
                 $text .= sprintf "%${len}.${len}s", $stamp;
                 next;
             }
@@ -545,8 +555,11 @@ You can also have more than one token on a single line. Here is an example:
     };
     $ctr->close;
 
-The C<token> method is used to update the token value. If '%k' is used, then the
-counter must be instantiated with an initial value for the token.
+The C<token> method is used to update the token value immediately on the screen.
+
+The C<tok_maybe> method is used to set the token value, but the screen is not refreshed immediately.
+
+If '%k' is used, then the counter must be instantiated with an initial value for the token.
 
 =item characters '%P'
 
